@@ -128,7 +128,7 @@ def main():
     parser.add_argument('--version', action="store_true", default=False)    
     
     saga_hadoop_group = parser.add_argument_group('Manage SAGA Hadoop clusters')
-    saga_hadoop_group.add_argument('--resource', action="store", nargs=1, metavar="RESOURCE_URL", 
+    saga_hadoop_group.add_argument('--resource', action="store", nargs="?", metavar="RESOURCE_URL", 
                               help="submit a job to specified resource, e.g. fork://localhost",
                               default="fork://localhost")
     saga_hadoop_group.add_argument('--working_directory', action="store", nargs="?", metavar="WORKING_DIRECTORY", 
